@@ -24,8 +24,8 @@
 
 #define MOD_NAME_PREFIX "QO"
 
-#define DEFAULT_MAX_BUCKET_SIZE 60
-#define DEFAULT_MAX_BTREE_SIZE 500
+
+
 
 #define ZODB_64BIT_INTS
 #define ZODB_UNSIGNED_KEY_INTS
